<!--
 * @Author         : mengshouer
 * @Date           : 2021-03-16 00:00:00
 * @LastEditors    : mengshouer
 * @LastEditTime   : 2021-03-16 00:00:00
 * @Description    : None
 * @GitHub         : https://github.com/mengshouer/nonebot_plugin_analysis_bilibili
-->

<p align="center">
  <a href="https://v2.nonebot.dev/"><img src="https://v2.nonebot.dev/logo.png" width="200" height="200" alt="nonebot"></a>
</p>

<div align="center">

# nonebot_plugin_analysis_bilibili


_✨ NoneBot bilibili视频、番剧解析插件 ✨_

</div>

<p align="center">
  <a href="https://raw.githubusercontent.com/cscs181/QQ-Github-Bot/master/LICENSE">
    <img src="https://img.shields.io/github/license/cscs181/QQ-Github-Bot.svg" alt="license">
  </a>
  <a href="https://pypi.python.org/pypi/nonebot-plugin-analysis-bilibili">
    <img src="https://img.shields.io/pypi/v/nonebot-plugin-analysis-bilibili.svg" alt="pypi">
  </a>
  <img src="https://img.shields.io/badge/python-3.8+-blue.svg" alt="python">
</p>

## 使用方式
私聊或群聊发送bilibili的小程序/链接

## 安装
pip install nonebot_plugin_analysis_bilibili

```
pip install --upgrade nonebot_plugin_analysis_bilibili
```
在 Nonebot2 入口文件（例如 bot.py ）增加：
``` python
nonebot.load_plugin("nonebot_plugin_analysis_bilibili")
```
